@@ -9,6 +9,7 @@ class FakePreseemModel:
     _companies = {} # company_uuid to Company object
     _elements = {}  # company_uuid to {element_uuid to Element object}
     _sites = {}     # company_uuid to {site_uuid to Site object}
+    _elem_disc = {} # company_uuid to {uuid to ElementDiscovery object}
 
     def _new_attrs():
         """Generate attributes for a new preseem-model object."""
@@ -78,6 +79,9 @@ class FakePreseemModel:
             return [copy.deepcopy(x) for x in FakePreseemModel._companies.values()]
 
 
+    class ElementDiscovery(BaseModelObject):
+        pass
+
     class Element(BaseModelObject):
         @classmethod
         async def Create(cls, **kwargs):
@@ -132,6 +136,62 @@ class FakePreseemModel:
                     else:
                         setattr(elem, attr, val)
 
+        @classmethod
+        async def CreateElementDiscovery(cls, **kwargs):
+            company_uuid = kwargs.get('company_uuid')
+            assert company_uuid
+            company = FakePreseemModel._companies[company_uuid]
+            obj = FakePreseemModel.ElementDiscovery(**FakePreseemModel._new_attrs(),
+                    company_uuid=company.uuid,
+                    name=kwargs.get('name'),
+                    management_ip=kwargs.get('management_ip'),
+                    site_uuid=kwargs.get('site_uuid'),
+                    source=kwargs.get('source'),
+                    source_id=kwargs.get('source_id'),
+                    intent_role_uuid=kwargs.get('intent_role_uuid'),
+                    element_uuid=kwargs.get('element_uuid'),
+                    status=kwargs.get('status'))
+            discs = FakePreseemModel._elem_disc.get(company.uuid)
+            if discs is None:
+                discs = FakePreseemModel._elem_disc[company_uuid] = {}
+            discs[obj.uuid] = obj
+            return copy.deepcopy(obj)
+
+        @classmethod
+        async def ListElementDiscovery(cls, **kwargs):
+            company_uuid = kwargs.get('company_uuid')
+            intent_role_uuid = kwargs.get('intent_role_uuid')
+            assert company_uuid
+            # the real impl returns empty list if the company doesn't exist
+            return [copy.deepcopy(x) for x in (FakePreseemModel._elem_disc.get(company_uuid) or {}).values() if not intent_role_uuid or intent_role_uuid == x.intent_role_uuid]
+
+        @classmethod
+        async def DeleteElementDiscovery(cls, **kwargs):
+            company_uuid = kwargs.get('company_uuid')
+            uuid = kwargs.get('uuid')
+            discs = FakePreseemModel._elem_disc[company_uuid]
+            if discs:
+                disc = discs.get(uuid)
+                if disc:
+                    del discs[uuid]
+
+        @classmethod
+        async def UpdateElementDiscovery(cls, **kwargs):
+            company_uuid = kwargs.get('company_uuid')
+            uuid = kwargs.get('uuid')
+            discs= FakePreseemModel._elem_disc[company_uuid]
+            if discs:
+                disc = discs.get(uuid)
+                for attr, val in kwargs.items():
+                    if attr == 'company_uuid' or attr == 'uuid':
+                        continue
+                    elif attr == 'inactive' and val is True:
+                        FakePreseemModel._set_inactive(disc)
+                    else:
+                        if getattr(disc, attr) != val:
+                            disc.updated_at = time.time()
+                        setattr(disc, attr, val)
+
 
     class Site(BaseModelObject):
         @classmethod
@@ -164,3 +224,20 @@ class FakePreseemModel:
                 site = sites.get(uuid)
                 if site:
                     del elems[uuid]
+
+        @classmethod
+        async def Update(cls, **kwargs):
+            company_uuid = kwargs.get('company_uuid')
+            uuid = kwargs.get('uuid')
+            sites = FakePreseemModel._sites[company_uuid]
+            if sites:
+                site = sites.get(uuid)
+                for attr, val in kwargs.items():
+                    if attr == 'company_uuid' or attr == 'uuid':
+                        continue
+                    elif attr == 'inactive' and val is True:
+                        FakePreseemModel._set_inactive(site)
+                    else:
+                        if getattr(site, attr) != val:
+                            site.updated_at = time.time()
+                        setattr(site, attr, val)
