@@ -18,6 +18,7 @@ of the design, but for now it's left that way.
 """
 import asyncio
 import concurrent
+import functools
 from importlib import import_module
 import logging
 import time
@@ -197,9 +198,9 @@ class PreseemGrpcClient(object):
                 if timeout:
                     try:
                         if collect_results:
-                            return await asyncio.wait_for(loop.run_in_executor(self._executor,  self._grpc_op_collect, op, req, metadata), timeout=timeout)
+                            return await asyncio.wait_for(loop.run_in_executor(self._executor, self._grpc_op_collect, op, req, metadata), timeout=timeout)
                         else:
-                            return await asyncio.wait_for(loop.run_in_executor(self._executor,  op, req, metadata=metadata), timeout=timeout)
+                            return await asyncio.wait_for(loop.run_in_executor(self._executor, functools.partial(op, req, metadata=metadata)), timeout=timeout)
                     except asyncio.TimeoutError:
                         logging.warning('GRPC operation timed out: %s', op)
                         raise
@@ -207,7 +208,7 @@ class PreseemGrpcClient(object):
                     if collect_results:
                         x = await loop.run_in_executor(self._executor, self._grpc_op_collect, op, req, metadata)
                     else:
-                        x = await loop.run_in_executor(self._executor, op, req, metadata=metadata)
+                        x = await loop.run_in_executor(self._executor, functools.partial(op, req, metadata=metadata))
                     return x
             except grpc.RpcError as err:
                 logging.debug('Error calling service: %s (%s)', err.code(), err.details())
