@@ -766,6 +766,22 @@ class Radio:
         else:
             self.pb.ClearField('tx_frutl')
 
+    @property
+    def wifi_mode(self):
+        return self.pb.wifi_mode if self.pb.HasField('wifi_mode') else None
+    @wifi_mode.setter
+    def wifi_mode(self, value):
+        if value is not None:
+            if value > 0:
+                self.pb.wifi_mode = value
+            else:  # not a valid enum value
+                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                        "Invalid value for Networkelement.Radio.wifi_mode",
+                        value=value, metric_name='NetworkElement.Radio.wifi_mode')
+                self.pb.ClearField('wifi_mode')
+        else:
+            self.pb.ClearField('wifi_mode')
+
 
 class Sector:
     def __init__(self, pb=None, errctx=None, **kwargs):
